@@ -70,6 +70,10 @@ class Image(NamedTuple):
             return NotImplemented
         return self.image_hash == other.image_hash and self.repository == other.repository
 
+    def to_schema(self) -> str:
+        """Schema reference for the given image."""
+        return self.repository.to_schema() + ":" + self.image_hash
+
     def get_parent_children(self) -> Tuple[Optional[str], List[str]]:
         """Gets the parent and a list of children of a given image."""
         parent = self.parent_id
@@ -117,8 +121,7 @@ class Image(NamedTuple):
         )
         if not result:
             raise TableNotFoundError(
-                "Image %s:%s does not have a table %s!"
-                % (self.repository, self.image_hash, table_name)
+                "Image %s does not have a table %s!" % (self.to_schema(), table_name)
             )
         table_schema, objects = result
         return Table(
@@ -126,7 +129,9 @@ class Image(NamedTuple):
         )
 
     @manage_audit
-    def checkout(self, force: bool = False, layered: bool = False) -> None:
+    def checkout(
+        self, force: bool = False, layered: bool = False, ddn_layout: bool = False
+    ) -> None:
         """
         Checks the image out, changing the current HEAD pointer. Raises an error
         if there are pending changes to its checkout.
@@ -134,6 +139,7 @@ class Image(NamedTuple):
         :param force: Discards all pending changes to the schema.
         :param layered: If True, uses layered querying to check out the image (doesn't materialize tables
             inside of it).
+        :param ddn_layout: Determines whether to rotate the name prefix of lower and overlay table/view
         """
         target_schema = self.repository.to_schema()
         if len(target_schema) > POSTGRES_MAX_IDENTIFIER:
@@ -163,7 +169,7 @@ class Image(NamedTuple):
             self.object_engine.delete_table(target_schema, table)
 
         if layered:
-            self.lq_checkout()
+            self.lq_checkout(ddn_layout=ddn_layout)
         else:
             for table in self.get_tables():
                 self.get_table(table).materialize(table)
@@ -212,9 +218,8 @@ class Image(NamedTuple):
                 continue
 
             logging.debug(
-                "Mounting %s:%s/%s into %s",
-                self.repository.to_schema(),
-                self.image_hash,
+                "Mounting %s/%s into %s",
+                self.to_schema(),
                 table_name,
                 target_schema,
             )
