@@ -235,9 +235,10 @@ class ForeignDataWrapperDataSource(MountableDataSource, SyncableDataSource, ABC)
         result_json = cast(
             List[Dict[str, Any]],
             self.engine.run_sql(
-                SQL("SELECT row_to_json(t.*) FROM {}.{} t LIMIT %s").format(
-                    Identifier(schema), Identifier(table)
-                ),
+                SQL(
+                    "WITH p AS MATERIALIZED(SELECT * FROM {}.{} LIMIT %s) "
+                    "SELECT row_to_json(p.*) FROM p"
+                ).format(Identifier(schema), Identifier(table)),
                 (limit,),
                 return_shape=ResultShape.MANY_ONE,
             ),
@@ -675,10 +676,34 @@ class PostgreSQLDataSource(ForeignDataWrapperDataSource):
                 "description": "Schema name to import data from",
                 "default": "public",
             },
+            "use_remote_estimate": {
+                "type": "boolean",
+                "default": False,
+                "title": "Use remote EXPLAIN",
+                "description": "Issue remote EXPLAIN commands to obtain cost estimates",
+            },
+            "fetch_size": {
+                "type": "integer",
+                "title": "Fetch size",
+                "description": "Number of rows from the remote server to get in each fetch operation",
+                "default": 10000,
+            },
         },
         "required": ["host", "port", "dbname", "remote_schema"],
     }
 
+    table_params_schema = merge_jsonschema(
+        ForeignDataWrapperDataSource.table_params_schema,
+        {
+            "type": "object",
+            "properties": {
+                "table_name": {"type": "string", "title": "Table name"},
+                "schema_name": {"type": "string", "title": "Schema name"},
+            },
+            "required": [],
+        },
+    )
+
     commandline_help: str = """Mount a Postgres database.
 
 Mounts a schema on a remote Postgres database as a set of foreign tables locally."""
@@ -699,6 +724,8 @@ If a dictionary, must have the format
             "host": self.params["host"],
             "port": str(self.params["port"]),
             "dbname": self.params["dbname"],
+            "use_remote_estimate": "true" if self.params.get("use_remote_estimate") else "false",
+            "fetch_size": int(self.params.get("fetch_size", 10000)),
             **self.params.get("extra_server_args", {}),
         }
 
@@ -707,7 +734,7 @@ If a dictionary, must have the format
 
     def get_table_options(self, table_name: str, tables: Optional[TableInfo] = None):
         options = super().get_table_options(table_name, tables)
-        options["schema_name"] = self.params["remote_schema"]
+        options["schema_name"] = options.get("schema_name", self.params["remote_schema"])
         return options
 
     def get_fdw_name(self):
