@@ -8,12 +8,12 @@ from tempfile import TemporaryDirectory
 from typing import TYPE_CHECKING, Any, Dict, List, Optional, cast
 
 from docker.types import LogConfig
-from ruamel.yaml import YAMLError
+from ruamel.yaml.error import YAMLError
 
 from splitgraph.ingestion.airbyte.docker_utils import (
     detect_network_mode,
     remove_at_end,
-    wait_not_failed,
+    wait_container,
 )
 from splitgraph.utils.docker import (
     copy_dir_to_container,
@@ -23,7 +23,7 @@ from splitgraph.utils.docker import (
 from splitgraph.utils.yaml import safe_dump, safe_load
 
 if TYPE_CHECKING:
-    from splitgraph.engine.postgres.engine import PsycopgEngine
+    from splitgraph.engine.postgres.psycopg import PsycopgEngine
 
 
 def prepare_git_repo(url: str, target_path: str, ref: str = "master") -> None:
@@ -193,7 +193,7 @@ def run_dbt_transformation_from_git(
         with remove_at_end(container):
             copy_dir_to_container(container, tmp_dir, "/data", exclude_names=[".git"])
             container.start()
-            wait_not_failed(container, mirror_logs=True)
+            wait_container(container, mirror_logs=True)
 
 
 def compile_dbt_manifest(
@@ -244,7 +244,7 @@ def compile_dbt_manifest(
         with remove_at_end(container):
             copy_dir_to_container(container, tmp_dir, "/data", exclude_names=[".git"])
             container.start()
-            wait_not_failed(container, mirror_logs=True)
+            wait_container(container, mirror_logs=True)
             # Extract the manifest
             return cast(
                 Dict[str, Any],
